@@ -1,7 +1,8 @@
 /*
  *  db.h
  *
- *  Copyright (c) 2002-2007 by Judd Vinet <jvinet@zeroflux.org>
+ *  Copyright (c) 2006-2009 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *  Copyright (c) 2005 by Aurelien Foret <orelien@chez.com>
  *  Copyright (c) 2006 by Miklos Vajna <vmiklos@frugalware.org>
  *
@@ -41,8 +42,9 @@ typedef enum _pmdbinfrq_t {
 struct __pmdb_t {
 	char *path;
 	char *treename;
-	void *handle;
+	unsigned short pkgcache_loaded;
 	alpm_list_t *pkgcache;
+	unsigned short grpcache_loaded;
 	alpm_list_t *grpcache;
 	alpm_list_t *servers;
 };
@@ -56,8 +58,6 @@ pmdb_t *_alpm_db_register_local(void);
 pmdb_t *_alpm_db_register_sync(const char *treename);
 
 /* be.c, backend specific calls */
-int _alpm_db_open(pmdb_t *db);
-void _alpm_db_close(pmdb_t *db);
 int _alpm_db_populate(pmdb_t *db);
 int _alpm_db_read(pmdb_t *db, pmpkg_t *info, pmdbinfrq_t inforeq);
 int _alpm_db_prepare(pmdb_t *db, pmpkg_t *info);
