@@ -308,7 +308,7 @@ static int sync_search(alpm_list_t *syncs, alpm_list_t *targets)
 			}
 
 			/* print the package size with the output if ShowSize option set */
-			if(config->showsize) {
+			if(!config->quiet && config->showsize) {
 				/* Convert byte size to MB */
 				double mbsize = alpm_pkg_get_size(pkg) / (1024.0 * 1024.0);
 
@@ -682,7 +682,7 @@ static int sync_trans(alpm_list_t *targets)
 				printf("%s/%s\n", dburl, alpm_pkg_get_filename(pkg));
 			} else {
 				/* can't use WARNING here, we don't show warnings in -Sp... */
-				pm_fprintf(stderr, PM_LOG_ERROR, _("no database for package: %s\n"),
+				pm_fprintf(stderr, PM_LOG_ERROR, _("no URL for package: %s\n"),
 						alpm_pkg_get_name(pkg));
 			}
 
@@ -837,18 +837,26 @@ int pacman_sync(alpm_list_t *targets)
 		/* check for newer versions of packages to be upgraded first */
 		alpm_list_t *packages = syncfirst();
 		if(packages) {
-			printf(_(":: The following packages should be upgraded first :\n"));
-			list_display("   ", packages);
-			if(yesno(_(":: Do you want to cancel the current operation\n"
-							":: and upgrade these packages now?"))) {
-				FREELIST(targs);
-				targs = packages;
-				config->flags = 0;
-				config->op_s_upgrade = 0;
+			/* Do not ask user if all the -S targets are SyncFirst packages, see FS#15810 */
+			alpm_list_t *tmp = NULL;
+			if(config->op_s_upgrade || (tmp = alpm_list_diff(targets, packages, (alpm_list_fn_cmp)strcmp))) {
+				alpm_list_free(tmp);
+				printf(_(":: The following packages should be upgraded first :\n"));
+				list_display("   ", packages);
+				if(yesno(_(":: Do you want to cancel the current operation\n"
+								":: and upgrade these packages now?"))) {
+					FREELIST(targs);
+					targs = packages;
+					config->flags = 0;
+					config->op_s_upgrade = 0;
+				} else {
+					FREELIST(packages);
+				}
+				printf("\n");
 			} else {
+				pm_printf(PM_LOG_DEBUG, "skipping SyncFirst dialog\n");
 				FREELIST(packages);
 			}
-			printf("\n");
 		}
 	}
 
