@@ -174,7 +174,8 @@ int rmrf(const char *path)
 			return(1);
 		}
 
-		if((dirp = opendir(path)) == (DIR *)-1) {
+		dirp = opendir(path);
+		if(!dirp) {
 			return(1);
 		}
 		for(dp = readdir(dirp); dp != NULL; dp = readdir(dirp)) {
